==> cayenne-4.0.3-src.tar.gz: cayenne-4.0.3-src/cayenne-server/src/main/java/org/apache/cayenne/tx/ExternalTransaction.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.tx;

import org.apache.cayenne.log.JdbcEventLogger;

/**
 * Represents a container-managed transaction.
 * 
 * @since 4.0
 */
public class ExternalTransaction extends BaseTransaction {

    protected JdbcEventLogger logger;

    public ExternalTransaction(JdbcEventLogger jdbcEventLogger) {
        this.logger = jdbcEventLogger;
    }

    @Override
    protected void processCommit() {
        logger.logCommitTransaction("no commit - transaction controlled externally.");
    }

    @Override
    protected void processRollback() {
        logger.logRollbackTransaction("no rollback - transaction controlled externally.");
    }

    @Override
    public boolean isExternal() {
        return true;
    }
}

==> cayenne-4.2.3-src.tar.gz: cayenne-4.2.3-src/cayenne-server/src/main/java/org/apache/cayenne/tx/ExternalTransaction.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.tx;

import org.apache.cayenne.log.JdbcEventLogger;

/**
 * Represents a container-managed transaction.
 * 
 * @since 4.0
 */
public class ExternalTransaction extends BaseTransaction {

    protected JdbcEventLogger logger;

    public ExternalTransaction(JdbcEventLogger jdbcEventLogger) {
        this(jdbcEventLogger, TransactionDescriptor.defaultDescriptor());
    }

    /**
     * @since 4.1
     */
    public ExternalTransaction(JdbcEventLogger jdbcEventLogger, TransactionDescriptor descriptor) {
        super(descriptor);
        this.logger = jdbcEventLogger;
    }

    @Override
    protected void processCommit() {
        logger.logCommitTransaction("no commit - transaction controlled externally.");
    }

    @Override
    protected void processRollback() {
        logger.logRollbackTransaction("no rollback - transaction controlled externally.");
    }

    @Override
    public boolean isExternal() {
        return true;
    }
}
